package mtpsapi

import (
	"testing"

	"git.rosy.net.cn/baseapi/utils"
)

func TestPagePoiUpdate(t *testing.T) {
	err := api.PagePoiUpdate("666730", "任学梅", "15283376640", "feng.shi@rosy.net.cn")
	if err != nil {
		t.Fatal(err)
	}
}

func TestGetAccountDetail(t *testing.T) {
	err := api.GetAccountDetail()
	if err != nil {
		t.Fatal(err)
	}
}

func TestGetStoreStatus(t *testing.T) {
	result, err := api.GetStoreStatus("肖坝路店")
	if err != nil {
		t.Fatal(err)
	}
	t.Log(utils.Format4Output(result, false))
}

func TestRefreshToken(t *testing.T) {
	result, err := api.RefreshToken()
	if err != nil {
		t.Fatal(err)
	}
	t.Log(utils.Format4Output(result, false))
}

func TestGetStoreInfo(t *testing.T) {
	result, err := api.GetStoreInfo(666772)
	if err != nil {
		t.Fatal(err)
	}
	t.Log(utils.Format4Output(result, false))
}

func TestGetStoreInfoByID(t *testing.T) {
	result, err := api.GetStoreInfoByID(800002)
	if err != nil {
		t.Fatal(err)
	}
	t.Log(utils.Format4Output(result, false))
}
